"""
A sample which provide print_lol().
"""


def print_lol(the_list, level=0):
    """print list"""
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            print('\t'*level, end='')
            print(each_item)



from distutils.core import setup

setup(
    name='nester9',
    version='1.2.0',
    description='A simple printer of nested lists',
    author='will',
    author_email='example@example.com',
    url='https://example.com',
    py_modules=['nester9']
)
